#!/bin/bash

help() {
  >&2 echo '
s6 compatibility script of:

usage: update-rc.d [-f] <basename> remove
       update-rc.d [-f] <basename> defaults
       update-rc.d [-f] <basename> defaults-disabled
       update-rc.d <basename> disable|enable [S|2|3|4|5]
		-f: force

The disable|enable API is not stable and might change in the future.
'
}

# discard all option parameters
while [[ $1 =~ ^- ]]; do
  if [ "$1" = '--help' ] || [ "$1" = '-h' ]; then
    help
    exit 0
  fi
  shift
done

# need at least 2 non-option arguments (service name and action)
if [ $# -lt 2 ]; then
  help
  exit 1
fi

# update databases, so we can check if service name exists
svctl compile && svctl update

# only manage service if it's known to s6
if svctl listall | grep -q "^${1}$"; then
  case "$2" in
    defaults-disabled|disable|remove)
      svctl disable "$1" || exit 1
      ;;
    defaults|enable)
      svctl enable "$1" || exit 1
      ;;
  esac
else
  echo "Service ${1} is unknown to s6."
fi

# make changes persistent
svctl compile && svctl update

exit 0
